/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// Local includes
#include "GameWidget.h"
#include "GameSpinBox.h"
#include "GameRadioButton.h"

// Qt includes
#include <QDebug>
#include <QGridLayout>
#include <QLabel>
#include <QCheckBox>

GameWidget::GameWidget(QWidget *parent, int game, int gamesPerRound, int boogerScore)
    : QWidget(parent), m_boogerScore(boogerScore)
{
    setAutoFillBackground(false);

    QGridLayout *layout = new QGridLayout(this);
    layout->addWidget(new QLabel(tr("<b>%1. Bobbl</b>").arg(QString::number(game))), 0, 0);

    for (int i = 1; i <= 2; i++) {
        layout->addWidget(new QLabel(tr("Paar %1").arg(QString::number(i))), i, 0);

        m_score[i] = new GameSpinBox;
        if (i == 1) {
            m_score[i]->setMaximum(m_boogerScore - 1);
        } else {
            m_score[i]->setMaximum(m_boogerScore);
        }
        layout->addWidget(m_score[i], i, 1);

        if (game == gamesPerRound) {
            connect(m_score[i], &GameSpinBox::enterPressed, this, &GameWidget::emitEnterPressed);
        }

        m_booger[i] = new GameRadioButton(this, m_score[i]);
        layout->addWidget(m_booger[i], i, 2);
        connect(m_booger[i], &QRadioButton::clicked, this, &GameWidget::toggleScore);
    }

    m_gameAborted = new QCheckBox;
    m_gameAborted->setToolTip(tr("Markiert den Bobbl als abgebrochen."));
    layout->addWidget(m_gameAborted, 1, 3, 2, 1);
    connect(m_gameAborted, &QCheckBox::stateChanged, this, &GameWidget::setGameAborted);
    m_gameAborted->hide();

    m_booger[1]->setChecked(Qt::Checked);
    m_score[2]->setValue(m_boogerScore);
    m_score[2]->setEnabled(false);
}

void GameWidget::toggleScore()
{
    for (int i = 1; i <= 2; i++) {
        if (m_booger[i]->isChecked()) {
            m_score[i]->setMaximum(m_boogerScore - 1);
            m_score[i]->setValue(0);
            m_score[i]->setEnabled(true);
            m_score[i]->setFocus();
            m_score[i]->selectAll();
        } else {
            m_score[i]->setMaximum(m_boogerScore);
            m_score[i]->setValue(m_boogerScore);
            m_score[i]->setEnabled(false);
        }
    }
}

int GameWidget::score(int pair)
{
    return m_score[pair]->value();
}

void GameWidget::emitEnterPressed()
{
    emit enterPressed();
}

void GameWidget::setScore(int pair1Score, int pair2Score)
{
    if (pair1Score == m_boogerScore) {
        m_booger[2]->setChecked(Qt::Checked);
    } else {
        m_booger[1]->setChecked(Qt::Checked);
    }
    toggleScore();
    m_score[1]->setValue(pair1Score);
    m_score[2]->setValue(pair2Score);
}

void GameWidget::abortRound(int state)
{
    m_gameAborted->setChecked(state == true);
    m_gameAborted->setVisible(state);
}

void GameWidget::setGameAborted(int state)
{
    if (state) {
        for (int i = 1; i <= 2; i++) {
            m_booger[i]->hide();
            m_score[i]->setEnabled(true);
            m_score[i]->setValue(0);
            m_score[i]->setMaximum(m_boogerScore - 1);
        }
        m_score[1]->setFocus();
        m_score[1]->selectAll();
    } else {
        m_booger[1]->show();
        m_booger[2]->show();
        m_booger[1]->setChecked(Qt::Checked);
        toggleScore();
    }
}
