/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SCOREPAGE_H
#define SCOREPAGE_H

// Local includes
#include "Database.h"

// Qt includes
#include <QWidget>
#include <QMap>

// Qt classes
class QComboBox;
class QGroupBox;
class QCheckBox;
class QVBoxLayout;
class QScrollArea;
class QPushButton;
class QTableWidget;
class QMenu;
class QAction;
class QHBoxLayout;
class QLabel;

// Local classes
class Database;
class GameWidget;

class ScorePage : public QWidget
{
    Q_OBJECT

public:
    explicit ScorePage(QWidget *parent, Database *db);
    void reload(int lastRound = -1, int abortRound = 0);
    void setScrollAreaHeight();

signals:
    void statusUpdate(QString message);
    void tournamentStarted();
    void scoreChanged();

protected:
    void showEvent(QShowEvent *event);

private slots:
    void openRound(int roundNumber);
    void tableChanged(int tableNumber);
    void pair1Changed(int pair);
    void pair2Changed(int pair);
    void pair34Changed(int pair);
    void saveScore();
    void triggerShowContextMenu();
    void showContextMenu(QPoint point);
    void editScore();
    void deleteScore();
    void checkEnterScore();

private: // Functions
    void updateScore();
    void pairChanged(int pairNumber, int pair);
    void doDeleteScore(int round, int table);

private: // Variables
    Database *m_db;
    bool m_disableChange;
    QComboBox *m_roundSelect;
    QGroupBox *m_playersBox;
    QComboBox *m_tableSelect;
    QMap<int, QMap<int, QComboBox *>> m_playersSelect;
    QCheckBox *m_autoSelect;
    QGroupBox *m_scoreBox;
    QVBoxLayout *m_scoreBoxLayout;
    QScrollArea *m_scoreBoxScroll;
    QWidget *m_scoreBoxWidget;
    QPushButton *m_saveScoreButton;
    QGroupBox *m_roundSummaryBox;
    QTableWidget *m_scoreList;
    QMenu *m_contextMenu;
    QLabel *m_menuTitle;
    QAction *m_editAction;
    QAction *m_deleteAction;
    QHBoxLayout *m_scoreBoxWidgetLayout;
    QMap<int, bool> m_roundsState;
    Database::Assignment m_assignment;
    QList<GameWidget *> m_gameWidgets;
    QCheckBox *m_abortRound;

};

#endif // SCOREPAGE_H
