/* Copyright (c) 2012-2017 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation in version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

// Qt includes
#include <QDialog>

// Qt classes
class QGroupBox;
class QRadioButton;
class QLabel;
class QSpinBox;
class QDialogButtonBox;

// Local Classes
class Database;

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent, Database *db);
    void resetGui();
    void reload();
    void setToSaved();
    void updateDatabaseInfo();

signals:
    void statusUpdate(QString message);
    void settingsSaved();
    void dbReset();

protected:
    void closeEvent(QCloseEvent *event);
    void reject();

private slots:
    void resetDatabase();
    void saveSettings();

private: // Variables
    Database *m_db;
    QLabel *m_fixedPairsDescription;
    QLabel *m_singlePlayersDescription;
    QGroupBox *m_databaseBox;
    QRadioButton *m_pairs;
    QRadioButton *m_singlePlayers;
    QLabel *m_fixedPairsLabel;
    QLabel *m_singlePlayersLabel;
    QSpinBox *m_boogerScore;
    QLabel *m_boogerScoreLabel;
    QSpinBox *m_gamesPerRound;
    QLabel *m_gamesPerRoundLabel;
    QLabel *m_dbFileLabel;
    QLabel *m_mtVersionHeaderLabel;
    QLabel *m_mtVersionLabel;
    QDialogButtonBox *m_buttonBox;

};

#endif // SETTINGSDIALOG_H
